# Simple API Key

Simple API Key is an API Key authentication plugin for REST API built with [Django Rest Framework](https://www.django-rest-framework.org/). 

For the full documentation, visit https://djangorestframework-simple-apikey.readthedocs.io/en/latest/.
